components

package
v0.0.29 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 3, 2026 License: BSD-2-Clause-Views Imports: 11 Imported by: 0

README

components

This module contains templ components for use by the server module when outputting HTML documents.

After modifying any .templ files run go generate to regenerate the code.

Documentation

Overview

templ: version: v0.3.977

Index

Constants

This section is empty.

Variables

var CSSFS embed.FS
var JsFS embed.FS

The "all:" prefix is needed here because by default files beginning with ‘.’ or ‘_’ are excluded and we want to include "_hyperscript.min.js"

Functions

func APITokensContent added in v0.0.25

func APITokensContent(orgName string, orgClientCreds []cdntypes.OrgClientCredentialSafe, flashMessages []string, tokenURL *url.URL, serverURL *url.URL) templ.Component

func ActivateServiceVersionContent

func ActivateServiceVersionContent(orgName string, serviceName string, version int64, err error) templ.Component

func ConsolePage

func ConsolePage(u *url.URL, title string, ad cdntypes.AuthData, orgName string, availableOrgNames []string, contents templ.Component) templ.Component

func CreateAPITokenContent added in v0.0.25

func CreateAPITokenContent(orgName string, atData APITokenData) templ.Component

func CreateDomainContent

func CreateDomainContent(orgName string, dData DomainData) templ.Component

func CreateServiceContent

func CreateServiceContent(orgName string, err error) templ.Component

func CreateServiceVersionContent

func CreateServiceVersionContent(serviceName string, orgName string, vclSK cdntypes.VclStepKeys, domains []cdntypes.Domain, originGroups []cdntypes.OriginGroup, submittedData *cdntypes.CreateServiceVersionForm, cloneData cdntypes.ServiceVersionCloneData, err error, errDetails string) templ.Component

func Dashboard

func Dashboard(dashData cdntypes.DashboardData) templ.Component

func DomainsContent

func DomainsContent(orgName string, domains []cdntypes.Domain, verificationTag string, tagSeparator string, flashMessages []string) templ.Component

func LoginPage

func LoginPage(returnTo string, loginFailed bool) templ.Component
func NavBar(u *url.URL, ad cdntypes.AuthData, orgName string, availableOrgNames []string) templ.Component

func NewAPITokenContent added in v0.0.25

func NewAPITokenContent(orgName string, newOrgCred cdntypes.NewOrgClientCredential, returnURL string) templ.Component

func OriginFieldSet

func OriginFieldSet(orgName string, serviceName string, index int, numFields int, submittedOrigin *cdntypes.CreateServiceVersionOrigin, cloneOrigin cdntypes.Origin, originGroups []cdntypes.OriginGroup, htmxRequest bool) templ.Component

func ServiceContent

func ServiceContent(orgName string, serviceName string, serviceVersions []cdntypes.ServiceVersion) templ.Component

func ServiceVersionContent

func ServiceVersionContent(serviceName string, sv cdntypes.ServiceVersionConfig, vclKeyToConf map[string]string, vclKeyOrder []string) templ.Component

func ServicesContent

func ServicesContent(orgName string, services []cdntypes.Service, flashMessages []string) templ.Component

Types

type APITokenData added in v0.0.25

type APITokenData struct {
	APITokenFormFields
	Errors APITokenErrors
}

type APITokenErrors added in v0.0.25

type APITokenErrors struct {
	APITokenFormFields
	ServerError string
}

type APITokenFormFields added in v0.0.25

type APITokenFormFields struct {
	Name        string
	Description string
}

type DomainData

type DomainData struct {
	DomainFormFields
	Errors DomainErrors
}

type DomainErrors

type DomainErrors struct {
	DomainFormFields
	ServerError string
}

type DomainFormFields

type DomainFormFields struct {
	Name string
}

Jump to